@@ -8,11 +8,6 @@ from graphmanagerlib.Data_for_gcn import getDataForUniquePrediction
 from torch_geometric.utils.convert import from_networkx
 from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects,ConvertPredictionToJson
 
-def clearOutputFolder(test_output_fd):
-    shutil.rmtree(test_output_fd)
-    if not os.path.exists(test_output_fd):
-        os.mkdir(test_output_fd)
-
 
 def make_info(document):
     connect = Grapher(document)
@@ -59,9 +54,5 @@ def predictionsUnique(saved_model_folder,json,labels_tab):
 
     return ConvertPredictionToJson(predictions)
 
-def load_predictionData(save_fd):
-    predictions_data = torch.load(os.path.join(save_fd, 'predictions_data.dataset'))
-    return predictions_data
-
 if __name__ == "__main__":
     predictionsUnique()
\ No newline at end of file
